#ifndef TaxiwayMapObject_h
#define TaxiwayMapObject_h

// For compilers that support precompilation, includes "wx.h".
#include <wx/wxprec.h>

#ifdef __BORLANDC__
#pragma hdrstop
#endif

#ifndef WX_PRECOMP
// Include your minimal set of headers here, or wx.h
#include <wx/wx.h>
#endif

#include "PavementMapObject.h"

class TaxiwayMapObject: public PavementMapObject {

        DECLARE_CLASS(TaxiwayMapObject)
        TRANSACTIONOBJECT_DEFINE_SMARTREF(TaxiwayMapObject);
        
public:
        TaxiwayMapObject(Airport::SmartRef airport,
                         Point3D center,
                         double length,
                         double width,
                         double heading,
                         Surface surface,
                         float smoothness,
                         bool edgeLights,
                         bool centerLights);

        virtual ~TaxiwayMapObject();

        virtual void Paint(wxDC& dc, MapEditor* editor, const MapPass& pass);

        virtual bool Hit(MapEditor* editor, TDRectangle r);

        virtual MapSelection* CreateSelection(MapSelectionManager* manager);

        virtual wxRect GetDeviceBounds(MapEditor* editor);

        virtual TDRectangle GetGeographicBounds();

        TRANSACTIONOBJECT_DEFINE_STATE_ACCESSOR(bool,CenterLights,hasCenterLights)
        TRANSACTIONOBJECT_DEFINE_STATE_ACCESSOR(bool,EdgeLights,hasEdgeLights)

        bool HasCenterLights() const { return GetCenterLights(); }
        bool HasEdgeLights() const { return GetEdgeLights(); }
protected:
        typedef struct {
                bool hasCenterLights;
                bool hasEdgeLights;
        } State;

        TRANSACTIONOBJECT_DEFINE_STATE_MEMENTO(TaxiwayMapObject,PavementMapObject,State)

};

#endif

