#if HAVE_CONFIG_H
#  include <config.h>
#endif /* HAVE_CONFIG_H */

#include "MapPropertyManager.h"

#include "MapEditor.h"

#include <wx/propgrid/propgrid.h>

IMPLEMENT_CLASS(MapPropertyManager,wxEvtHandler);
IMPLEMENT_CLASS(MapUpdatePropertiesEvent,wxEvent);

DEFINE_EVENT_TYPE(wxEVT_MAP_UPDATE_PROPERTIES);

BEGIN_EVENT_TABLE(MapPropertyManager,wxEvtHandler)
        EVT_MAP_UPDATE_PROPERTIES(MapPropertyManager::OnUpdateProperties)
        EVT_PG_CHANGED(wxID_ANY,MapPropertyManager::PropertyChanged)
END_EVENT_TABLE()

MapPropertyManager::MapPropertyManager(wxPropertyGrid* grid):
        _managedGrid(grid),
        _updateEventPosted(false)
{
        _managedGrid->PushEventHandler(this);
}

MapPropertyManager::~MapPropertyManager() {
        _managedGrid->RemoveEventHandler(this);
}

void MapPropertyManager::SchedulePropertyUpdate() {
        if (_updateEventPosted)
                return;
        MapUpdatePropertiesEvent updateEvent(wxEVT_MAP_UPDATE_PROPERTIES);
        AddPendingEvent(updateEvent);
        _updateEventPosted=true;
}

void MapPropertyManager::OnUpdateProperties(MapUpdatePropertiesEvent&) {
        UpdateProperties();
}

void MapPropertyManager::UpdateProperties() {
        _updateEventPosted=false;
}

void MapPropertyManager::BeforeObjectChange(TransactionObject* object) {
        // NOOP
}

void MapPropertyManager::AfterObjectChange(TransactionObject* object) {
        SchedulePropertyUpdate();
}

