#ifndef CollisionUtils_h
#define CollisionUtils_h

// For compilers that support precompilation, includes "wx.h".
#include <wx/wxprec.h>

#ifdef __BORLANDC__
#pragma hdrstop
#endif

#ifndef WX_PRECOMP
// Include your minimal set of headers here, or wx.h
#include <wx/wx.h>
#endif

#include "TDRectangle.h"

class Point3D;

class CollisionUtils {
public:
        /**
         * \brief Determine whether two convex polygons collide/intersect.
         *
         * \param n1    The number of points for the first polygon.
         * \param pts1  The points of the first polygon.
         * \param n2    The number of points for the second polygon.
         * \param pts2  The points of the second polygon.
         *
         * \return true, if and only if the polygons collide/intersect.
         */
        static bool ConvexPolygonsCollide(size_t n1, const Point3D* pts1,
                                          size_t n2, const Point3D* pts2);
        
        /** 
         * \brief Determine whether a rectangle intersects a convex polgyon.
         *
         * \param r     The rectangle.
         * \param n     The number of points for the polygon.
         * \param pts   The points of the polygon.
         *
         * \return true, iff the polygon intersects the rectangle.
         */
        static bool ConvexPolygonRectangleCollide(TDRectangle r, size_t n, const Point3D *pts);
        
        /**
         * \brief Determine whether a rectangle intersects a circle.
         *
         * \param rect  The rectangle
         * \param c     The circle center
         * \param r     The circle radius
         */
        static bool IntersectsCircle(TDRectangle rect, Point3D c, double r);
protected:
        static bool CheckOverlap(size_t n1, const Point3D* pts1,
                                 size_t n2, const Point3D* pts2);
};

#endif /* CollisionUtils_h */

