#if HAVE_CONFIG_H
#  include <config.h>
#endif /* HAVE_CONFIG_H */

#include "Transaction.h"

IMPLEMENT_CLASS(Transaction,wxObject);

Transaction::Transaction() {
        _committed=false;
}

Transaction::~Transaction() {
        MementoMap::iterator it;
        for (it=_mementos.begin();it!=_mementos.end();it++) {
                delete it->second;
        }
}

void Transaction::StoreCopy(TransactionObject* obj) {
        if (_mementos.find(obj)!=_mementos.end())
                return;
        wxObject* memento=obj->CreateMemento();
        _mementos[obj]=memento;
}

void Transaction::DeleteCopy(TransactionObject* obj) {
        MementoMap::iterator it=_mementos.find(obj);
        if (it==_mementos.end()) {
                return;
	}
        delete it->second;
        _mementos.erase(it);
}

void Transaction::Commit(const wxString& description) {
        _committed=true;
        _description=description;
        
        /* Mark all objects as clean */
        MementoMap::iterator it;
        for (it=_mementos.begin();it!=_mementos.end();it++)
                it->first->_dirty=false;
}

void Transaction::Restore() {
        /* restore all objects */
        MementoMap::iterator it;
        for (it=_mementos.begin();it!=_mementos.end();it++) {
                TransactionObject* obj=it->first;
                /*
                 * explictly mark the object as dirty to avoid storing
                 * of additional copies due to calls to TransactionObject::BeforeWrite().
                 *
                 * We call BeforeWrite() and AfterWrite() explicitly here to avoid
                 * adding these calls at the beginning and end of each RestoreMemento()
                 * override, thereby triggering multiple calls through all the
                 * inheritance hierarchy.
                 */
                obj->_dirty=true;
                
                obj->BeforeWrite();
                
                obj->RestoreMemento(it->second);
                
                obj->AfterWrite();
                
                obj->_dirty=false;
        }
}

void Transaction::AddCurrentCopiesToTransaction(Transaction* target) {
        MementoMap::iterator it;
        for (it=_mementos.begin();it!=_mementos.end();it++) {
                wxASSERT(it->first);
                target->StoreCopy(it->first);
        }
}

