#ifndef TransactionObjectChangeListener_h
#define TransactionObjectChangeListener_h

class TransactionObject;

/**
 * \brief A TransactionObjectChangeListener is notified of changes to an object it is
 * registered with.
 *
 * The listener both is notified before and after the change.
 *
 * \sa TransactionObject::RegisterChangeListener() TransactionObject::UnregisterChangeListener()
 */
class TransactionObjectChangeListener {
public:
        virtual ~TransactionObjectChangeListener() {}

        /**
         * \brief Prepare for an upcoming change.
         *
         * This is called by the object before a change is about to happen.
         *
         * \note Rationale: Many objects listening for changes on TransactionObject
         * instance need to do some action before the change, such as triggering
         * a redraw on the region occupied by a MapObject or its selection
         * before the change.
         *
         * \sa TransactionObject::BeforeWrite()
         */
        virtual void BeforeObjectChange(TransactionObject* object)=0;
        
        /**
         * \brief A change has happened.
         *
         * This is called by the object after a change happened.
         *
         * \sa TransactionObject::AfterWrite()
         */
        virtual void AfterObjectChange(TransactionObject* object)=0;
};

#endif
